@@ -33,9 +33,10 @@
 #  define PACKAGE_DEPRECATED_NO_EXPORT PACKAGE_NO_EXPORT PACKAGE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define PACKAGE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef PACKAGE_NO_DEPRECATED
+#    define PACKAGE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
